@@ -13,6 +13,7 @@ from dataquality.loggers.logger_config.base_logger_config import (
     BaseLoggerConfig,
     base_logger_config,
 )
+from dataquality.schemas.split import Split, conform_split
 from dataquality.schemas.task_type import TaskType
 
 try:
@@ -47,9 +48,21 @@ class BaseLoggerAttributes(str, Enum):
     gold = "gold"
     emb = "emb"
     probs = "probs"
+    logits = "logits"
     epoch = "epoch"
     data_error_potential = "data_error_potential"
     aum = "aum"
+    text_tokenized = "text_tokenized"
+    gold_spans = "gold_spans"
+    pred_emb = "pred_emb"
+    gold_emb = "gold_emb"
+    pred_spans = "pred_spans"
+    dep_scores = "dep_scores"
+    text_token_indices = "text_token_indices"
+    gold_dep = "gold_dep"
+    pred_dep = "pred_dep"
+    text_token_indices_flat = "text_token_indices_flat"
+    user_helper_data = "user_helper_data"
 
     @staticmethod
     def get_valid() -> List[str]:
@@ -74,7 +87,15 @@ class BaseGalileoLogger:
 
     @abstractmethod
     def validate(self) -> None:
-        ...
+        if not self.split:
+            if self.logger_config.cur_split:
+                self.split = self.logger_config.cur_split
+            else:
+                raise GalileoException(
+                    "You didn't log a split and did not set a split. Use "
+                    "`dataquality.set_split` to set the split"
+                )
+        self.split = self.validate_split(self.split)
 
     def is_valid(self) -> bool:
         try:
@@ -165,3 +186,7 @@ class BaseGalileoLogger:
     @classmethod
     def doc(cls) -> None:
         print(cls.__doc__)
+
+    @classmethod
+    def validate_split(cls, split: Union[str, Split]) -> str:
+        return conform_split(split).value
