@@ -1,9 +1,9 @@
-import os
-from importlib import reload
 from random import random
 from typing import Callable
 
+import numpy as np
 import pytest
+import vaex
 
 import dataquality
 import dataquality.core._config
@@ -11,10 +11,11 @@ from dataquality.exceptions import GalileoException
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.thread_pool import ThreadPoolManager
+from tests.conftest import TEST_PATH
 from tests.utils.data_utils import (
     NUM_LOGS,
     NUM_RECORDS,
-    _log_data,
+    _log_text_classification_data,
     validate_cleanup_data,
     validate_uploaded_data,
 )
@@ -30,9 +31,11 @@ def test_threaded_logging_and_upload(
     Tests that threaded calls to upload still yield non-missing datasets
     """
     num_records = 32
-    num_logs = 200
+    num_logs = 20
     num_emb = 50
-    _log_data(num_records=num_records, num_logs=num_logs, num_emb=num_emb)
+    _log_text_classification_data(
+        num_records=num_records, num_logs=num_logs, num_emb=num_emb
+    )
     try:
         # Equivalent to the users `finish` call, but we don't want to clean up files yet
         ThreadPoolManager.wait_for_threads()
@@ -55,9 +58,9 @@ def test_multi_label_logging(
     """
     set_test_config(task_type=TaskType.text_multi_label)
     num_records = 32
-    num_logs = 200
+    num_logs = 20
     num_emb = 50
-    _log_data(
+    _log_text_classification_data(
         num_records=num_records, num_logs=num_logs, num_emb=num_emb, multi_label=True
     )
     try:
@@ -84,11 +87,11 @@ def test_metadata_logging(
     meta = {}
     for i in meta_cols:
         meta[i] = [random() for _ in range(NUM_RECORDS * NUM_LOGS)]
-    _log_data(meta=meta)
+    _log_text_classification_data(meta=meta)
     try:
         # Equivalent to the users `finish` call, but we don't want to clean up files yet
         ThreadPoolManager.wait_for_threads()
-        c = dataquality.get_data_logger("text_classification")
+        c = dataquality.get_data_logger()
         c.upload()
         validate_uploaded_data(meta_cols=meta_cols)
         c._cleanup()
@@ -98,6 +101,50 @@ def test_metadata_logging(
         ThreadPoolManager.wait_for_threads()
 
 
+def test_metadata_logging_different_splits(
+    cleanup_after_use: Callable, set_test_config: Callable
+) -> None:
+    """
+    Tests that logging metadata columns only attach to the splits we log them for
+    """
+    dataquality.set_labels_for_run(["APPLE", "ORANGE"])
+    input_data = {
+        "text": ["sentence_1", "sentence_2"],
+        "labels": ["APPLE", "ORANGE"],
+        "split": "training",
+        "meta": {"train_meta_1": [1, 2]},
+        "ids": [1, 2],
+    }
+    dataquality.log_input_data(**input_data)
+    input_data["split"] = "test"
+    input_data["meta"] = {"test_meta_1": ["foo", "bar"]}
+    dataquality.log_input_data(**input_data)
+
+    output_data = {
+        "emb": np.random.rand(2, 100),
+        "logits": np.random.rand(2, 5),
+        "ids": [1, 2],
+        "split": "training",
+        "epoch": 0,
+    }
+    dataquality.log_model_outputs(**output_data)
+    output_data["split"] = "test"
+    dataquality.log_model_outputs(**output_data)
+    dataquality.get_data_logger().upload()
+
+    train_data = vaex.open(f"{TEST_PATH}/training/0/data/data.hdf5")
+    test_data = vaex.open(f"{TEST_PATH}/test/0/data/data.hdf5")
+
+    assert "train_meta_1" in train_data.get_column_names()
+    assert "train_meta_1" not in test_data.get_column_names()
+
+    assert "test_meta_1" in test_data.get_column_names()
+    assert "test_meta_1" not in train_data.get_column_names()
+
+    assert sorted(train_data["train_meta_1"].tolist()) == [1, 2]
+    assert sorted(test_data["test_meta_1"].tolist()) == ["bar", "foo"]
+
+
 def test_metadata_logging_invalid(
     cleanup_after_use: Callable, set_test_config: Callable
 ) -> None:
@@ -120,7 +167,7 @@ def test_metadata_logging_invalid(
     for i in range(MAX_META_COLS):
         meta[f"attr_{i}"] = [random() for _ in range(NUM_RECORDS * NUM_LOGS)]
 
-    _log_data(meta=meta)
+    _log_text_classification_data(meta=meta)
     valid_meta_cols = ["test1", "meta2"]
     valid_meta_cols += [f"attr_{i}" for i in range(44)]
     try:
@@ -142,7 +189,7 @@ def test_logging_duplicate_ids(
     Tests that logging duplicate ids triggers a failure
     """
     num_records = 50
-    _log_data(num_records=num_records, unique_ids=False)
+    _log_text_classification_data(num_records=num_records, unique_ids=False)
     try:
         # Equivalent to the users `finish` call, but we don't want to clean up files yet
         ThreadPoolManager.wait_for_threads()
@@ -152,20 +199,3 @@ def test_logging_duplicate_ids(
     finally:
         # Mock finish() call without calling the API
         ThreadPoolManager.wait_for_threads()
-
-
-def test_config_no_vars(monkeypatch):
-    """Should throw a nice error if we don't set our env vars"""
-    x = os.getenv("GALILEO_API_URL")
-    os.environ["GALILEO_API_URL"] = ""
-    if os.path.isfile(".galileo/config.json"):
-        os.remove(".galileo/config.json")
-
-    monkeypatch.setattr("builtins.input", lambda inp: "" if "region" in inp else "test")
-    monkeypatch.setattr("getpass.getpass", lambda _: "test_pass")
-
-    reload(dataquality.core._config)
-    assert dataquality.core._config.config.api_url == "http://test"
-    assert dataquality.core._config.config.minio_region == "us-east-1"
-
-    os.environ["GALILEO_API_URL"] = x
