@@ -45,6 +45,7 @@ class NewsgroupDataset(torch.utils.data.Dataset):
         self.dataset["text"] = newsgroups.data
         self.dataset["label"] = newsgroups.target
         self.dataset = self.dataset[:NUM_RECORDS]
+        self.glogger = dataquality.get_data_logger()()
 
         # Shuffle some percentage of the training dataset
         # to force create mislabeled samples
@@ -54,9 +55,8 @@ class NewsgroupDataset(torch.utils.data.Dataset):
         #
         # 🔭 Logging Inputs with Galileo!
         #
-        self.gconfig = dataquality.get_data_logger()(
-            text=self.dataset["text"], labels=self.dataset["label"]
-        )
+        self.glogger.text = self.dataset["text"]
+        self.glogger.labels = self.dataset["label"]
 
         tokenizer = DistilBertTokenizerFast.from_pretrained("distilbert-base-uncased")
         self.encodings = tokenizer(
@@ -81,14 +81,14 @@ class TorchDistilBERTTorch(pl.LightningModule):
         )
         self.feature_extractor = AutoModel.from_pretrained("distilbert-base-uncased")
 
-    def forward(self, x, attention_mask, x_idxs, epoch, split):
+    def forward(self, x, attention_mask, x_idxs):
         # Fake model building for less memory usage
-        probs = [[random() for _ in range(5)] for _ in range(NUM_RECORDS)]
+        logits = [[random() for _ in range(5)] for _ in range(NUM_RECORDS)]
         emb = [[random() for _ in range(10)] for _ in range(NUM_RECORDS)]
 
         # Logging with Galileo!
-        self.g_model_config = dataquality.get_model_logger()(
-            emb=emb, probs=probs, ids=x_idxs, split=split, epoch=epoch
+        self.glogger = dataquality.get_model_logger()(
+            emb=emb, logits=logits, ids=x_idxs
         )
 
         return 0
@@ -102,14 +102,14 @@ class LightningDistilBERT(pl.LightningModule):
         )
         self.feature_extractor = AutoModel.from_pretrained("distilbert-base-uncased")
 
-    def forward(self, x, attention_mask, x_idxs, epoch, split):
+    def forward(self, x, attention_mask, x_idxs):
         # Fake model building for less memory usage
-        probs = [[random() for _ in range(5)] for _ in range(NUM_RECORDS)]
+        logits = [[random() for _ in range(5)] for _ in range(NUM_RECORDS)]
         emb = [[random() for _ in range(10)] for _ in range(NUM_RECORDS)]
 
         # Logging with Galileo!
-        self.g_model_config = dataquality.get_model_logger()(
-            emb=emb, probs=probs, ids=x_idxs
+        self.glogger = dataquality.get_model_logger()(
+            emb=emb, logits=logits, ids=x_idxs
         )
 
         return 0
@@ -121,8 +121,6 @@ class LightningDistilBERT(pl.LightningModule):
             x=x,
             attention_mask=attention_mask,
             x_idxs=x_idxs,
-            epoch=self.current_epoch,
-            split="training",
         )
 
     def validation_step(self, batch, batch_idx):
@@ -132,8 +130,6 @@ class LightningDistilBERT(pl.LightningModule):
             x=x,
             attention_mask=attention_mask,
             x_idxs=x_idxs,
-            epoch=self.current_epoch,
-            split="validation",
         )
 
     def test_step(self, batch, batch_idx):
@@ -143,8 +139,6 @@ class LightningDistilBERT(pl.LightningModule):
             x=x,
             attention_mask=attention_mask,
             x_idxs=x_idxs,
-            epoch=self.current_epoch,
-            split="test",
         )
 
     def configure_optimizers(self):
